@@ -55,6 +55,8 @@
 
 #include "shumate/shumate-vector-sprite.h"
 #include "shumate/shumate-vector-sprite-sheet.h"
+#include "shumate/shumate-vector-reader.h"
+#include "shumate/shumate-vector-reader-iter.h"
 #include "shumate/shumate-vector-renderer.h"
 
 #undef __SHUMATE_SHUMATE_H_INSIDE__
